==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/BatteryThreeQuarters.md <==
# BatteryThreeQuarters


```text
fontawesome-6/Solid/BatteryThreeQuarters
```

```text
include('fontawesome-6/Solid/BatteryThreeQuarters')
```



| Illustration | BatteryThreeQuarters |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/BatteryThreeQuarters.png) | ![illustration for BatteryThreeQuarters](../../fontawesome-6/Solid/BatteryThreeQuarters.Local.png) |




## BatteryThreeQuarters

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element BatteryThreeQuarters
include('fontawesome-6/Solid/BatteryThreeQuarters')

' renders the element
BatteryThreeQuarters('BatteryThreeQuarters', 'Battery Three Quarters', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element BatteryThreeQuarters
include('fontawesome-6/Solid/BatteryThreeQuarters')

' renders the element
BatteryThreeQuarters('BatteryThreeQuarters', 'Battery Three Quarters', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/fontawesome-6/Solid/BatteryThreeQuarters.md <==
# BatteryThreeQuarters


```text
fontawesome-6/Solid/BatteryThreeQuarters
```

```text
include('fontawesome-6/Solid/BatteryThreeQuarters')
```



| Illustration | BatteryThreeQuarters |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/BatteryThreeQuarters.png) | ![illustration for BatteryThreeQuarters](../../fontawesome-6/Solid/BatteryThreeQuarters.Local.png) |




## BatteryThreeQuarters

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element BatteryThreeQuarters
include('fontawesome-6/Solid/BatteryThreeQuarters')

' renders the element
BatteryThreeQuarters('BatteryThreeQuarters', 'Battery Three Quarters', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element BatteryThreeQuarters
include('fontawesome-6/Solid/BatteryThreeQuarters')

' renders the element
BatteryThreeQuarters('BatteryThreeQuarters', 'Battery Three Quarters', 'an optional tech label', 'an optional description')
@enduml
```
